﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Linq;
using System.Runtime.CompilerServices;
using System.Text;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Media;
using WriteErase.ClassBase;
using WriteErase.ClassData;

namespace WriteErase.ClassBase
{
    public partial class Order: INotifyPropertyChanged
    {
        public SolidColorBrush colorBorder
        {
            get
            {
                int countInStock = 0;
                int countOutStock = 0;

                foreach (OrderProduct op in OrderProduct)
                {
                    if (op.Product.ProductQuantityInStock >= op.ProductCount)
                        countInStock++;
                    else
                        countOutStock++;
                }

                if (countOutStock >= 1)
                    return new SolidColorBrush((Color)ColorConverter.ConvertFromString("#ff8c00"));
                else if (countInStock >= 3)
                    return new SolidColorBrush((Color)ColorConverter.ConvertFromString("#20b2aa"));
                else
                    return new SolidColorBrush(Colors.Black);
            }
        }

        public double CostWithDiscount
        {
            get
            {
                double cost = 0;

                foreach (OrderProduct op in OrderProduct)
                {
                    cost += op.Product.Cost * op.ProductCount;
                }

                return cost;
            }
        }

        public double CostWithoutDiscount
        {
            get
            {
                double cost = 0;

                foreach (OrderProduct op in OrderProduct)
                {
                    cost += (double)op.Product.ProductCost * op.ProductCount;
                }

                return cost;
            }
        }

        public double ProcentCost
        {
            get => Math.Round((1 - CostWithDiscount / CostWithoutDiscount) * 100, 2);
        }

        List<String> statusList = new List<string>() { "Новый", "Завершен" };

        public List<String> StatusList { get => statusList; }

        int status = -1;

        public int Status
        {
            get
            {
                if (status == -1)
                {
                    if (OrderStatus == "Новый")
                        status = 0;
                    else
                        status = 1;
                }
                return status;
            }
            set
            {
                if (OrderStatus == "Завершен")
                {
                    MessageBox.Show("Вы не можете редактировать уже завершенные заказы");
                    value = 1;
                }
                else if (OrderStatus != statusList[value] && value == 0)
                {
                    OrderStatus = statusList[value];
                    BaseConnection.kotBase.SaveChanges();
                    status = value;
                }
                OnPropertyChanged();
            }
        }

        public DateTime SelectDate
        {
            get => (DateTime)OrderDeliveryDate;
            set
            {
                if (value > DateTime.Now.AddDays(-1) && OrderStatus != "Завершен")
                {
                    OrderDeliveryDate = value;
                    BaseConnection.kotBase.SaveChanges();
                }
                else
                {
                    if (OrderStatus == "Завершен")
                        MessageBox.Show("Вы не можете редактировать уже завершенные заказы");
                    if (value <= DateTime.Now.AddDays(-1))
                        MessageBox.Show("Дата доставки не может быть меньше текущей");
                }
            }
        }

        public event PropertyChangedEventHandler PropertyChanged;
        public void OnPropertyChanged([CallerMemberName] string prop = "")
        {
            if (PropertyChanged != null)
                PropertyChanged(this, new PropertyChangedEventArgs(prop));
        }
    }
}
